@@ -5,6 +5,6 @@ Attributes:
 """
 
 SPACY_PKG = {
-  "en": "en_core_web_md",
-  "es": "es_core_news_md",
+  "en": "en_core_web_trf",
+  "es": "es_dep_news_trf",
 }
